==> mfc-api-model-0.1.1-sources.jar: com/valor/mfc/vms/api/model/cloud/CloudAcctDo.java <==
package com.valor.mfc.vms.api.model.cloud;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

/**
 * Created by Frank.Huang on 2016/10/18.
 */
public class CloudAcctDo extends AbstractPrintable {
    private long cid = 0L;
    private String site = "";
    private String acct = "";
    private String acctAlias     = "";
    private String refreshStatus = "";
    private String statusMsg     = "";
    private Long   refreshTime   = 0L;
    private int    fileCount     = 0;
    private String checksum      = "";
    private long length          = 0L;
    private long updateTS        = 0L;
    private String loginType = "";
    private String loginKey  = "";
    private int newAccount   = 0;
    private long lastRefreshSuccessTS = 0L;
    private int accountType   = 0;
    private long createTime=0;
    private long expiredTime=0;
    private long pkgId;


    public long getCid() {
        return cid;
    }

    public void setCid(long cid) {
        this.cid = cid;
    }

    public String getSite() {
        return site;
    }

    public void setSite(String site) {
        this.site = site;
    }

    public void setSite(ECloudSite site) {
        this.site = site.name();
    }


    public String getAcct() {
        return acct;
    }

    public void setAcct(String acct) {
        this.acct = acct;
    }

    public String getStatusMsg() {
        return statusMsg;
    }

    public void setStatusMsg(String statusMsg) {
        this.statusMsg = statusMsg;
    }

    public Long getRefreshTime() {
        return refreshTime;
    }

    public void setRefreshTime(Long refreshTime) {
        this.refreshTime = refreshTime;
    }

    public int getFileCount() {
        return fileCount;
    }

    public void setFileCount(int fileCount) {
        this.fileCount = fileCount;
    }

    public String getRefreshStatus() {
        return refreshStatus;
    }

    public void setRefreshStatus(String refreshStatus) {
        this.refreshStatus = refreshStatus;
    }

    public void setRefreshStatus(ECloudAcctStatus refreshStatus) {
        this.refreshStatus = refreshStatus.name();
    }

    public String getChecksum() {
        return checksum;
    }

    public void setChecksum(String checksum) {
        this.checksum = checksum;
    }

    public long getLength() {
        return length;
    }

    public void setLength(long length) {
        this.length = length;
    }

    public long getUpdateTS() {
        return updateTS;
    }

    public void setUpdateTS(long updateTS) {
        this.updateTS = updateTS;
    }

    public String getAcctAlias() {
        return acctAlias;
    }

    public void setAcctAlias(String acctAlias) {
        this.acctAlias = acctAlias;
    }

    public String getLoginType() {
        return loginType;
    }

    public void setLoginType(String loginType) {
        this.loginType = loginType;
    }

    public String getLoginKey() {
        return loginKey;
    }

    public void setLoginKey(String loginKey) {
        this.loginKey = loginKey;
    }

    public int getNewAccount() {
        return newAccount;
    }

    public void setNewAccount(int newAccount) {
        this.newAccount = newAccount;
    }

    public long getLastRefreshSuccessTS() {
        return lastRefreshSuccessTS;
    }

    public void setLastRefreshSuccessTS(long lastRefreshSuccessTS) {
        this.lastRefreshSuccessTS = lastRefreshSuccessTS;
    }

    public int getAccountType() {
        return accountType;
    }

    public void setAccountType(int accountType) {
        this.accountType = accountType;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public long getPkgId() {
        return pkgId;
    }

    public void setPkgId(long pkgId) {
        this.pkgId = pkgId;
    }

    public long getExpiredTime() {
        return expiredTime;
    }

    public void setExpiredTime(long expiredTime) {
        this.expiredTime = expiredTime;
    }
}

==> mfc-api-model-0.1.3-sources.jar: com/valor/mfc/vms/api/model/cloud/CloudAcctDo.java <==
package com.valor.mfc.vms.api.model.cloud;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

/**
 * Created by Frank.Huang on 2016/10/18.
 */
public class CloudAcctDo extends AbstractPrintable {
    private long cid = 0L;
    private String site = "";
    private String acct = "";
    private String acctAlias     = "";
    private String refreshStatus = "";
    private String statusMsg     = "";
    private Long   refreshTime   = 0L;
    private int    fileCount     = 0;
    private String checksum      = "";
    private long length          = 0L;
    private long updateTS        = 0L;
    private String loginType = "";
    private String loginKey  = "";
    private int newAccount   = 0;
    private long lastRefreshSuccessTS = 0L;
    private int accountType   = 0;
    private long createTime=0;
    private long expiredTime=0;
    private long pkgId;
    private String refreshStatusInfo = "";

    public String getRefreshStatusInfo() {
        return refreshStatusInfo;
    }

    public void setRefreshStatusInfo(String refreshStatusInfo) {
        this.refreshStatusInfo = refreshStatusInfo;
    }

    public long getCid() {
        return cid;
    }

    public void setCid(long cid) {
        this.cid = cid;
    }

    public String getSite() {
        return site;
    }

    public void setSite(String site) {
        this.site = site;
    }

    public void setSite(ECloudSite site) {
        this.site = site.name();
    }


    public String getAcct() {
        return acct;
    }

    public void setAcct(String acct) {
        this.acct = acct;
    }

    public String getStatusMsg() {
        return statusMsg;
    }

    public void setStatusMsg(String statusMsg) {
        this.statusMsg = statusMsg;
    }

    public Long getRefreshTime() {
        return refreshTime;
    }

    public void setRefreshTime(Long refreshTime) {
        this.refreshTime = refreshTime;
    }

    public int getFileCount() {
        return fileCount;
    }

    public void setFileCount(int fileCount) {
        this.fileCount = fileCount;
    }

    public String getRefreshStatus() {
        return refreshStatus;
    }

    public void setRefreshStatus(String refreshStatus) {
        this.refreshStatus = refreshStatus;
    }

    public void setRefreshStatus(ECloudAcctStatus refreshStatus) {
        this.refreshStatus = refreshStatus.name();
    }

    public String getChecksum() {
        return checksum;
    }

    public void setChecksum(String checksum) {
        this.checksum = checksum;
    }

    public long getLength() {
        return length;
    }

    public void setLength(long length) {
        this.length = length;
    }

    public long getUpdateTS() {
        return updateTS;
    }

    public void setUpdateTS(long updateTS) {
        this.updateTS = updateTS;
    }

    public String getAcctAlias() {
        return acctAlias;
    }

    public void setAcctAlias(String acctAlias) {
        this.acctAlias = acctAlias;
    }

    public String getLoginType() {
        return loginType;
    }

    public void setLoginType(String loginType) {
        this.loginType = loginType;
    }

    public String getLoginKey() {
        return loginKey;
    }

    public void setLoginKey(String loginKey) {
        this.loginKey = loginKey;
    }

    public int getNewAccount() {
        return newAccount;
    }

    public void setNewAccount(int newAccount) {
        this.newAccount = newAccount;
    }

    public long getLastRefreshSuccessTS() {
        return lastRefreshSuccessTS;
    }

    public void setLastRefreshSuccessTS(long lastRefreshSuccessTS) {
        this.lastRefreshSuccessTS = lastRefreshSuccessTS;
    }

    public int getAccountType() {
        return accountType;
    }

    public void setAccountType(int accountType) {
        this.accountType = accountType;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public long getPkgId() {
        return pkgId;
    }

    public void setPkgId(long pkgId) {
        this.pkgId = pkgId;
    }

    public long getExpiredTime() {
        return expiredTime;
    }

    public void setExpiredTime(long expiredTime) {
        this.expiredTime = expiredTime;
    }
}
